@@ -6,8 +6,8 @@ import logging
 import typing
 from enum import Enum
 from pathlib import Path
+import shutil
 
-from . import compedit
 from . import vivado_hls_tcl as vtcl
 from . import vivado_report as vrpt
 from .tmpdir import TmpDirManager
@@ -87,7 +87,7 @@ class Experiment:
     def add_defines(self, defines: _define_list):
         self._defines.extend(defines)
 
-    def _generate_script(self, vivado_script: Path):
+    def _generate_script(self, vivado_script: Path, pipeline: bool, depth_constraint:typing.Optional[int] = None):
         with vivado_script.open('w') as vs:
             vtcl.create_project(vs,
                                 "vivado_hls_synthesis",
@@ -98,7 +98,9 @@ class Experiment:
                                 self._standard,
                                 "solution",
                                 self._part,
-                                self._clock_period
+                                self._clock_period,
+                                pipeline,
+                                depth_constraint
                                 )
             vtcl.csynth_solution_script(vs)
             if self._exp_type == ExperienceType.CSYNTH_ONLY:
@@ -126,11 +128,11 @@ class Experiment:
             raise FileNotFoundError(f"Error when starting experiment: component file {comp} does not exist")
         with TmpDirManager(self._exp_name, not self._keep_env):
             comp_copy = Path("comp.cpp")
-            compedit.decorate_comp(comp, comp_copy, depth_constraint)
-            logger.debug("Adding pragma decoration")
+            shutil.copyfile(comp, comp_copy)
 
             vivado_script = Path("vivado_script.tcl")
-            self._generate_script(vivado_script)
+            pipeline = depth_constraint is None or depth_constraint > 1
+            self._generate_script(vivado_script, pipeline, depth_constraint)
             run_script(vivado_script)
 
             vivado_hls_rpt = (Path() / "vivado_hls_synthesis" / "solution" /
