@@ -6,7 +6,9 @@ import typing
 _opt_str = typing.Optional[str]
 
 
-def create_project(file, project_name, filename, comp_name, includes, defines, standard, solution_name, part, period):
+def create_project(file, project_name, filename, comp_name, includes, defines,
+                   standard, solution_name, part, period, pipeline,
+                   depth_constraint):
     """
     Generate a tcl script for an HLS component creation
     :param filename: name of the file containing hls code
@@ -19,6 +21,8 @@ def create_project(file, project_name, filename, comp_name, includes, defines, s
     :param includes: list of include directories
     :param defines: list of defines
     :param standard: c++ standard code to use
+    :param pipeline: should vivado pipeline the design
+    :depth_constraint: depth_constraint to set
     """
     file.write("open_project {}\n".format(project_name))
     file.write("set_top {}\n".format(comp_name))
@@ -42,6 +46,13 @@ def create_project(file, project_name, filename, comp_name, includes, defines, s
     file.write('create_clock -period {} -name default\n'.format(
         period
     ))
+    #file.write('set_clock_uncertainty 0.0 default\n')
+    file.write('set_directive_interface -mode ap_ctrl_none [get_top]\n')
+    file.write('set_directive_inline -recursive [get_top]\n')
+    if pipeline and (depth_constraint is None or depth_constraint > 1):
+        file.write('set_directive_pipeline -II 1 [get_top]\n')
+    if depth_constraint is not None:
+        file.write('set_directive_latency -min {} -max {} [get_top]\n'.format(depth_constraint, depth_constraint))
 
 
 def csynth_solution_script(file):
