@@ -27,9 +27,9 @@ def parse_syn_report(synth_report_file):
         res['worst_case_latency'] = __getText(pipeline_depth.childNodes)
         res['II'] = __getText(pipeline_II.childNodes)
         res['pipelined'] = True
-    except KeyError:
-        res['worst_case_latency'] = '0'
-        res['II'] = '0'
+    except (KeyError, IndexError, ValueError):
+        res['worst_case_latency'] = '1'
+        res['II'] = '1'
         res['pipelined'] = False
     return res
 
